==> google-cloud-firestore-2.5.0.tar.gz: google-cloud-firestore-2.5.0/google/cloud/firestore_v1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .common import (
    DocumentMask,
    Precondition,
    TransactionOptions,
)
from .document import (
    ArrayValue,
    Document,
    MapValue,
    Value,
)
from .firestore import (
    BatchGetDocumentsRequest,
    BatchGetDocumentsResponse,
    BatchWriteRequest,
    BatchWriteResponse,
    BeginTransactionRequest,
    BeginTransactionResponse,
    CommitRequest,
    CommitResponse,
    CreateDocumentRequest,
    DeleteDocumentRequest,
    GetDocumentRequest,
    ListCollectionIdsRequest,
    ListCollectionIdsResponse,
    ListDocumentsRequest,
    ListDocumentsResponse,
    ListenRequest,
    ListenResponse,
    PartitionQueryRequest,
    PartitionQueryResponse,
    RollbackRequest,
    RunQueryRequest,
    RunQueryResponse,
    Target,
    TargetChange,
    UpdateDocumentRequest,
    WriteRequest,
    WriteResponse,
)
from .query import (
    Cursor,
    StructuredQuery,
)
from .write import (
    DocumentChange,
    DocumentDelete,
    DocumentRemove,
    DocumentTransform,
    ExistenceFilter,
    Write,
    WriteResult,
)

__all__ = (
    "DocumentMask",
    "Precondition",
    "TransactionOptions",
    "ArrayValue",
    "Document",
    "MapValue",
    "Value",
    "BatchGetDocumentsRequest",
    "BatchGetDocumentsResponse",
    "BatchWriteRequest",
    "BatchWriteResponse",
    "BeginTransactionRequest",
    "BeginTransactionResponse",
    "CommitRequest",
    "CommitResponse",
    "CreateDocumentRequest",
    "DeleteDocumentRequest",
    "GetDocumentRequest",
    "ListCollectionIdsRequest",
    "ListCollectionIdsResponse",
    "ListDocumentsRequest",
    "ListDocumentsResponse",
    "ListenRequest",
    "ListenResponse",
    "PartitionQueryRequest",
    "PartitionQueryResponse",
    "RollbackRequest",
    "RunQueryRequest",
    "RunQueryResponse",
    "Target",
    "TargetChange",
    "UpdateDocumentRequest",
    "WriteRequest",
    "WriteResponse",
    "Cursor",
    "StructuredQuery",
    "DocumentChange",
    "DocumentDelete",
    "DocumentRemove",
    "DocumentTransform",
    "ExistenceFilter",
    "Write",
    "WriteResult",
)

==> google-cloud-firestore-2.7.1.tar.gz: google-cloud-firestore-2.7.1/google/cloud/firestore_v1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .aggregation_result import (
    AggregationResult,
)
from .common import (
    DocumentMask,
    Precondition,
    TransactionOptions,
)
from .document import (
    ArrayValue,
    Document,
    MapValue,
    Value,
)
from .firestore import (
    BatchGetDocumentsRequest,
    BatchGetDocumentsResponse,
    BatchWriteRequest,
    BatchWriteResponse,
    BeginTransactionRequest,
    BeginTransactionResponse,
    CommitRequest,
    CommitResponse,
    CreateDocumentRequest,
    DeleteDocumentRequest,
    GetDocumentRequest,
    ListCollectionIdsRequest,
    ListCollectionIdsResponse,
    ListDocumentsRequest,
    ListDocumentsResponse,
    ListenRequest,
    ListenResponse,
    PartitionQueryRequest,
    PartitionQueryResponse,
    RollbackRequest,
    RunAggregationQueryRequest,
    RunAggregationQueryResponse,
    RunQueryRequest,
    RunQueryResponse,
    Target,
    TargetChange,
    UpdateDocumentRequest,
    WriteRequest,
    WriteResponse,
)
from .query import (
    Cursor,
    StructuredAggregationQuery,
    StructuredQuery,
)
from .write import (
    DocumentChange,
    DocumentDelete,
    DocumentRemove,
    DocumentTransform,
    ExistenceFilter,
    Write,
    WriteResult,
)

__all__ = (
    "AggregationResult",
    "DocumentMask",
    "Precondition",
    "TransactionOptions",
    "ArrayValue",
    "Document",
    "MapValue",
    "Value",
    "BatchGetDocumentsRequest",
    "BatchGetDocumentsResponse",
    "BatchWriteRequest",
    "BatchWriteResponse",
    "BeginTransactionRequest",
    "BeginTransactionResponse",
    "CommitRequest",
    "CommitResponse",
    "CreateDocumentRequest",
    "DeleteDocumentRequest",
    "GetDocumentRequest",
    "ListCollectionIdsRequest",
    "ListCollectionIdsResponse",
    "ListDocumentsRequest",
    "ListDocumentsResponse",
    "ListenRequest",
    "ListenResponse",
    "PartitionQueryRequest",
    "PartitionQueryResponse",
    "RollbackRequest",
    "RunAggregationQueryRequest",
    "RunAggregationQueryResponse",
    "RunQueryRequest",
    "RunQueryResponse",
    "Target",
    "TargetChange",
    "UpdateDocumentRequest",
    "WriteRequest",
    "WriteResponse",
    "Cursor",
    "StructuredAggregationQuery",
    "StructuredQuery",
    "DocumentChange",
    "DocumentDelete",
    "DocumentRemove",
    "DocumentTransform",
    "ExistenceFilter",
    "Write",
    "WriteResult",
)
